summaryrefslogtreecommitdiffhomepage
path: root/Sources/cplusplus.cc
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal.elmahrouss@icloud.com>2024-05-08 23:49:39 +0200
committerAmlal El Mahrouss <amlal.elmahrouss@icloud.com>2024-05-08 23:49:39 +0200
commitaed39642ea46602e16096f93ee163e8dbd53d1b7 (patch)
tree7f5cd179488b6a8a31a206cd248160c5f633624d /Sources/cplusplus.cc
parentddd4aa836761ddd5749ec78962b1eff78cb3719f (diff)
MHR-21: :boom: refactor.
Signed-off-by: Amlal El Mahrouss <amlal.elmahrouss@icloud.com>
Diffstat (limited to 'Sources/cplusplus.cc')
-rw-r--r--Sources/cplusplus.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/Sources/cplusplus.cc b/Sources/cplusplus.cc
index e729f54..c464b9f 100644
--- a/Sources/cplusplus.cc
+++ b/Sources/cplusplus.cc
@@ -2,7 +2,7 @@
* ========================================================
*
* ccplus
- * Copyright Mahrouss Logic, all rights reserved.
+ * Copyright SoftwareLabs, all rights reserved.
*
* ========================================================
*/
@@ -14,7 +14,7 @@
#define kPrintF printf
#define kSplashCxx() \
- kPrintF(kWhite "%s\n", "Mahrouss C++ Compiler, Copyright Mahrouss Logic.")
+ kPrintF(kWhite "%s\n", "LightSpeed C++ Compiler, Copyright SoftwareLabs.")
#include <Headers/AsmKit/CPU/amd64.hpp>
#include <Headers/ParserKit.hpp>
@@ -29,9 +29,9 @@
#define kOk 0
-/* Mahrouss Logic C++ driver */
+/* SoftwareLabs C++ driver */
/* This is part of CodeTools C++ compiler. */
-/* (c) Mahrouss Logic */
+/* (c) SoftwareLabs */
// @author Amlal El Mahrouss (amlel)
// @file cc.cc
@@ -152,7 +152,7 @@ static bool kOnForLoop = false;
static bool kInBraces = false;
static size_t kBracesCount = 0UL;
/* @brief C++ compiler backend for Mahrouss Logic C++ */
class CompilerBackendCPlusPlus final : public ParserKit::CompilerBackend {
public:
explicit CompilerBackendCPlusPlus() = default;
@@ -152,7 +152,7 @@ static bool kOnForLoop = false;
static bool kInBraces = false;
static size_t kBracesCount = 0UL;
-/* @brief C++ compiler backend for Mahrouss Logic C++ */
+/* @brief C++ compiler backend for SoftwareLabs C++ */
class CompilerBackendCPlusPlus final : public ParserKit::CompilerBackend {
public: